import { ACQuery, PDQuery, Options, PDResult } from './types';
/** Class containing methods to get results from Google Places */
export default class GPlaces {
    /** API options */
    options: Options;
    /**
     * Create an instance of the GPlaces class.
     * @param   {Options} [options=]
     *          Options for creating the handler
     */
    constructor(options: Options);
    /**
     * Make a request expecting a JSON response
     * @param   {string} [url='']
     *          Request URL for Google Maps
     * @private
     */
    request: (url?: string) => Promise<any>;
    /**
     * Search for places using specified options
     * @param   {string} [options='']
     *          Options string for the API call
     * @returns {Promise<ACResults>}
     *          Returns an unaltered array of results from the Google Places API
     */
    autocompleteRequest: (options?: string) => Promise<import("./types").ACResult[]>;
    /**
     * Search for places matching input
     * @param   {string} [input='']
     *          Input string for the search
     * @param   {ACQuery} [query=]
     *          Query object for the search
     * @returns {Promise<ACResults>}
     *          Returns an unaltered array of results from the Google Places API
     */
    search: (input?: string, query?: ACQuery | undefined) => Promise<import("./types").ACResult[]>;
    /**
     * Search for places matching input
     * @param   {string} [input='']
     *          Input string for the search
     * @param   {number} [radius=1000]
     *          Radius in meters to look for places
     * @param   {ACQuery} [query=]
     *          Query object for the search
     * @returns {Promise<ACResults>}
     *          Returns an unaltered array of results from the Google Places API
     */
    searchNearby: (input?: string, radius?: number, query?: ACQuery | undefined) => Promise<import("./types").ACResult[]>;
    /**
     * Search for places matching input
     * @param   {string} [placeid='']
     *          Place ID string of the requested place
     * @param   {PDQuery} [query=]
     *          Place ID string of the requested place
     * @returns {Promise<PDResult>}
     *          Returns an unaltered result object from the Google Places API
     */
    getPlaceDetails: (placeid?: string, query?: PDQuery | undefined) => Promise<PDResult>;
}
